==> foop_loyalty_plugin-0.9.1.tar.gz: lib/models/rewards_list_response.dart <==
import 'package:foop_loyalty_plugin/models/postcreate.dart';

class RewardsListResponse {
  String? statusCode;
  String? message;
  List<RewardsItem>? rows;
  int? total;

  RewardsListResponse({this.statusCode, this.message, this.rows, this.total});

  RewardsListResponse.fromJson(Map<String, dynamic> json) {
    statusCode = json['statusCode'];
    message = json['message'];
    if (json['rows'] != null) {
      rows = <RewardsItem>[];
      json['rows'].forEach((v) {
        rows!.add(RewardsItem.fromJson(v));
      });
    }
    total = json['total'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['statusCode'] = this.statusCode;
    data['message'] = this.message;
    if (this.rows != null) {
      data['rows'] = this.rows!.map((v) => v.toJson()).toList();
    }
    data['total'] = this.total;
    return data;
  }
}

class RewardsItem {
  int? id;
  int? standardLoyaltyProgramTypesId;
  int? businessId;
  List<MediaDetails>? mediaUrls;
  String? title;
  String? subtitle;
  List<String>? recipientType;
  List<RecipientDetails>? recipientDetails;
  Null? startDatetime;
  Null? endDatetime;
  int? incentiveCoins;
  String? incentiveCash;
  String? incentiveCurrency;
  String? status;
  RedemptionDetails? redemptionDetails;
  int? createdByUserId;
  String? createdDate;
  Null? createdFromIp;
  Null? updatedByUserId;
  String? updatedDate;
  Null? updatedFromIp;

  RewardsItem(
      {this.id,
        this.standardLoyaltyProgramTypesId,
        this.businessId,
        this.mediaUrls,
        this.title,
        this.subtitle,
        this.recipientType,
        this.recipientDetails,
        this.startDatetime,
        this.endDatetime,
        this.incentiveCoins,
        this.incentiveCash,
        this.incentiveCurrency,
        this.status,
        this.redemptionDetails,
        this.createdByUserId,
        this.createdDate,
        this.createdFromIp,
        this.updatedByUserId,
        this.updatedDate,
        this.updatedFromIp});

  RewardsItem.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    standardLoyaltyProgramTypesId = json['standard_loyalty_program_types_id'];
    businessId = json['business_id'];
    if (json['media_urls'] != null) {
      mediaUrls = []; //MediaDetails>();
      json['media_urls'].forEach((v) {
        mediaUrls!.add(MediaDetails.fromJson(v));
      });
    }
    title = json['title'];
    subtitle = json['subtitle'];
    if(json['recipient_type']!=null) {
      recipientType = json['recipient_type'].cast<String>();
    }
    if (json['recipient_details'] != null) {
      recipientDetails = <RecipientDetails>[];
      json['recipient_details'].forEach((v) {
        recipientDetails!.add(new RecipientDetails.fromJson(v));
      });
    }
    startDatetime = json['start_datetime'];
    endDatetime = json['end_datetime'];
    incentiveCoins = json['incentive_coins'];
    incentiveCash = json['incentive_cash'];
    incentiveCurrency = json['incentive_currency'];
    status = json['status'];
    redemptionDetails = json['redemption_details'] != null
        ? new RedemptionDetails.fromJson(json['redemption_details'])
        : null;
    createdByUserId = json['created_by_user_id'];
    createdDate = json['created_date'];
    createdFromIp = json['created_from_ip'];
    updatedByUserId = json['updated_by_user_id'];
    updatedDate = json['updated_date'];
    updatedFromIp = json['updated_from_ip'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['standard_loyalty_program_types_id'] =
        this.standardLoyaltyProgramTypesId;
    data['business_id'] = this.businessId;
    if (this.mediaUrls != null) {
      data['media_urls'] = this.mediaUrls!.map((v) => v.toJson()).toList();
    }
    data['title'] = this.title;
    data['subtitle'] = this.subtitle;
    data['recipient_type'] = this.recipientType;
    if (this.recipientDetails != null) {
      data['recipient_details'] =
          this.recipientDetails!.map((v) => v.toJson()).toList();
    }
    data['start_datetime'] = this.startDatetime;
    data['end_datetime'] = this.endDatetime;
    data['incentive_coins'] = this.incentiveCoins;
    data['incentive_cash'] = this.incentiveCash;
    data['incentive_currency'] = this.incentiveCurrency;
    data['status'] = this.status;
    if (this.redemptionDetails != null) {
      data['redemption_details'] = this.redemptionDetails!.toJson();
    }
    data['created_by_user_id'] = this.createdByUserId;
    data['created_date'] = this.createdDate;
    data['created_from_ip'] = this.createdFromIp;
    data['updated_by_user_id'] = this.updatedByUserId;
    data['updated_date'] = this.updatedDate;
    data['updated_from_ip'] = this.updatedFromIp;
    return data;
  }
}

class RecipientDetails {
  int? id;
  String? type;

  RecipientDetails({this.id, this.type});

  RecipientDetails.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    type = json['type'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['type'] = this.type;
    return data;
  }
}

class RedemptionDetails {
  int? giftCash;
  int? giftCoinsForCash;
  int? couponDiscountPercentage;
  int? couponCoinsForDiscountPercentage;

  RedemptionDetails(
      {this.giftCash,
        this.giftCoinsForCash,
        this.couponDiscountPercentage,
        this.couponCoinsForDiscountPercentage});

  RedemptionDetails.fromJson(Map<String, dynamic> json) {
    giftCash = json['gift_cash'];
    giftCoinsForCash = json['gift_coins_for_cash'];
    couponDiscountPercentage = json['coupon_discount_percentage'];
    couponCoinsForDiscountPercentage =
    json['coupon_coins for_discount_percentage'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['gift_cash'] = this.giftCash;
    data['gift_coins_for_cash'] = this.giftCoinsForCash;
    data['coupon_discount_percentage'] = this.couponDiscountPercentage;
    data['coupon_coins for_discount_percentage'] =
        this.couponCoinsForDiscountPercentage;
    return data;
  }
}

==> foop_loyalty_plugin-0.11.1.tar.gz: lib/models/rewards_list_response.dart <==
import 'package:foop_loyalty_plugin/models/postcreate.dart';

class RewardsListResponse {
  String? statusCode;
  String? message;
  List<RewardsItem>? rows;
  int? total;

  RewardsListResponse({this.statusCode, this.message, this.rows, this.total});

  RewardsListResponse.fromJson(Map<String, dynamic> json) {
    statusCode = json['statusCode'];
    message = json['message'];
    if (json['rows'] != null) {
      rows = <RewardsItem>[];
      json['rows'].forEach((v) {
        rows!.add(RewardsItem.fromJson(v));
      });
    }
    total = json['total'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['statusCode'] = this.statusCode;
    data['message'] = this.message;
    if (this.rows != null) {
      data['rows'] = this.rows!.map((v) => v.toJson()).toList();
    }
    data['total'] = this.total;
    return data;
  }
}

class RewardsItem {
  int? id;
  int? standardLoyaltyProgramTypesId;
  int? businessId;
  List<MediaDetails>? mediaUrls;
  String? title;
  String? subtitle;
  List<String>? recipientType;
  List<RecipientDetails>? recipientDetails;
  int? startDatetime;
  int? endDatetime;
  int? incentiveCoins;
  String? incentiveCash;
  String? incentiveCurrency;
  String? status;
  RedemptionDetails? redemptionDetails;
  int? createdByUserId;
  String? createdDate;
  String? createdFromIp;
  int? updatedByUserId;
  String? updatedDate;
  String? updatedFromIp;

  RewardsItem(
      {this.id,
        this.standardLoyaltyProgramTypesId,
        this.businessId,
        this.mediaUrls,
        this.title,
        this.subtitle,
        this.recipientType,
        this.recipientDetails,
        this.startDatetime,
        this.endDatetime,
        this.incentiveCoins,
        this.incentiveCash,
        this.incentiveCurrency,
        this.status,
        this.redemptionDetails,
        this.createdByUserId,
        this.createdDate,
        this.createdFromIp,
        this.updatedByUserId,
        this.updatedDate,
        this.updatedFromIp});

  RewardsItem.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    standardLoyaltyProgramTypesId = json['standard_loyalty_program_types_id'];
    businessId = json['business_id'];
    if (json['media_urls'] != null) {
      mediaUrls = []; //MediaDetails>();
      json['media_urls'].forEach((v) {
        mediaUrls!.add(MediaDetails.fromJson(v));
      });
    }
    title = json['title'];
    subtitle = json['subtitle'];
    if(json['recipient_type']!=null) {
      recipientType = json['recipient_type'].cast<String>();
    }
    if (json['recipient_details'] != null) {
      recipientDetails = <RecipientDetails>[];
      json['recipient_details'].forEach((v) {
        recipientDetails!.add(new RecipientDetails.fromJson(v));
      });
    }
    startDatetime = json['start_datetime'];
    endDatetime = json['end_datetime'];
    incentiveCoins = json['incentive_coins'];
    incentiveCash = json['incentive_cash'];
    incentiveCurrency = json['incentive_currency'];
    status = json['status'];
    redemptionDetails = json['redemption_details'] != null
        ? new RedemptionDetails.fromJson(json['redemption_details'])
        : null;
    createdByUserId = json['created_by_user_id'];
    createdDate = json['created_date'];
    createdFromIp = json['created_from_ip'];
    updatedByUserId = json['updated_by_user_id'];
    updatedDate = json['updated_date'];
    updatedFromIp = json['updated_from_ip'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['standard_loyalty_program_types_id'] =
        this.standardLoyaltyProgramTypesId;
    data['business_id'] = this.businessId;
    if (this.mediaUrls != null) {
      data['media_urls'] = this.mediaUrls!.map((v) => v.toJson()).toList();
    }
    data['title'] = this.title;
    data['subtitle'] = this.subtitle;
    data['recipient_type'] = this.recipientType;
    if (this.recipientDetails != null) {
      data['recipient_details'] =
          this.recipientDetails!.map((v) => v.toJson()).toList();
    }
    data['start_datetime'] = this.startDatetime;
    data['end_datetime'] = this.endDatetime;
    data['incentive_coins'] = this.incentiveCoins;
    data['incentive_cash'] = this.incentiveCash;
    data['incentive_currency'] = this.incentiveCurrency;
    data['status'] = this.status;
    if (this.redemptionDetails != null) {
      data['redemption_details'] = this.redemptionDetails!.toJson();
    }
    data['created_by_user_id'] = this.createdByUserId;
    data['created_date'] = this.createdDate;
    data['created_from_ip'] = this.createdFromIp;
    data['updated_by_user_id'] = this.updatedByUserId;
    data['updated_date'] = this.updatedDate;
    data['updated_from_ip'] = this.updatedFromIp;
    return data;
  }
}

class RecipientDetails {
  int? id;
  String? type;

  RecipientDetails({this.id, this.type});

  RecipientDetails.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    type = json['type'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['id'] = this.id;
    data['type'] = this.type;
    return data;
  }
}

class RedemptionDetails {
  num? giftCash;
  num? giftCoinsForCash;
  num? couponDiscountPercentage;
  num? couponCoinsForDiscountPercentage;

  RedemptionDetails(
      {this.giftCash,
        this.giftCoinsForCash,
        this.couponDiscountPercentage,
        this.couponCoinsForDiscountPercentage});

  RedemptionDetails.fromJson(Map<String, dynamic> json) {
    giftCash = json['gift_cash'];
    giftCoinsForCash = json['gift_coins_for_cash'];
    couponDiscountPercentage = json['coupon_discount_percentage'];
    couponCoinsForDiscountPercentage =
    json['coupon_coins for_discount_percentage'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['gift_cash'] = this.giftCash;
    data['gift_coins_for_cash'] = this.giftCoinsForCash;
    data['coupon_discount_percentage'] = this.couponDiscountPercentage;
    data['coupon_coins for_discount_percentage'] =
        this.couponCoinsForDiscountPercentage;
    return data;
  }
}
